package com.agilecontrol.nea.core.schema;

import com.agilecontrol.nea.core.schema.Column;
import com.agilecontrol.nea.core.schema.TableManager;
import com.agilecontrol.nea.util.NDSRuntimeException;
import com.agilecontrol.nea.util.PairTable;
import java.io.Serializable;
import java.util.Hashtable;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DisplaySetting implements Serializable {

   private static final long serialVersionUID = 3357929591748717174L;
   private static Logger logger = LoggerFactory.getLogger(DisplaySetting.class);
   public static final int OBJ_TEXT = 1;
   public static final int OBJ_TEXTAREA = 2;
   public static final int OBJ_SELECT = 3;
   public static final int OBJ_RAIDO = 4;
   public static final int OBJ_CHECK = 5;
   public static final int OBJ_HR = 6;
   public static final int OBJ_BLANK = 7;
   public static final int OBJ_FILE = 8;
   public static final int OBJ_IMAGE = 9;
   public static final int OBJ_BUTTON = 10;
   public static final int OBJ_CLOB = 11;
   public static final int OBJ_XML = 12;
   public static final int OBJ_ICON = 13;
   private static Hashtable methods = new Hashtable();
   private int objType;
   private int rows;
   private int columns;
   private int charsPerRow;


   public String getObjectTypeString() {
      String s = "";
      switch(this.objType) {
      case 1:
         s = "text";
         break;
      case 2:
         s = "textarea";
         break;
      case 3:
         s = "select";
         break;
      case 4:
         s = "radio";
         break;
      case 5:
         s = "check";
         break;
      case 6:
         s = "hr";
         break;
      case 7:
         s = "blank";
         break;
      case 8:
         s = "file";
         break;
      case 9:
         s = "image";
         break;
      case 10:
         s = "button";
         break;
      case 11:
         s = "clob";
         break;
      case 12:
         s = "xml";
         break;
      case 13:
         s = "icon";
      }

      return s;
   }

   public DisplaySetting(String type) {
      this(type, (Column)null);
   }

   public DisplaySetting(Column col) {
      this((String)null, col);
   }

   public DisplaySetting(String type, Column col) {
      try {
         if(type == null) {
            this.checkOnColumn(col);
         } else {
            type = type.trim().toLowerCase();
            int q = type.indexOf(40);
            String grossType = null;
            int t;
            int se;
            if(q != -1) {
               grossType = type.substring(0, q);
               t = type.indexOf(40) + 1;
               int comma = type.indexOf(44);
               se = type.indexOf(41);
               String p;
               if(comma != -1) {
                  p = type.substring(t, comma);
                  String s = type.substring(comma + 1, se);
                  this.columns = (new Integer(p)).intValue();
                  this.rows = (new Integer(s)).intValue();
               } else {
                  p = type.substring(t, se);
                  this.columns = (new Integer(p)).intValue();
                  this.rows = 1;
               }
            } else {
               grossType = type;
               this.columns = 1;
               this.rows = 1;
            }

            t = type.indexOf(91) + 1;
            se = type.indexOf(93);
            if(t != 0) {
               this.charsPerRow = (new Integer(type.substring(t, se))).intValue();
            } else {
               if(this.rows == 1 && this.columns == 1) {
                  this.charsPerRow = 20;
               }

               if(this.rows == 1 && this.columns > 1) {
                  this.charsPerRow = 80;
               }

               if(this.rows > 1 && this.columns > 1) {
                  this.charsPerRow = 60;
               }
            }

            Integer t1 = (Integer)methods.get(grossType);
            if(t1 == null) {
               throw new NDSRuntimeException(" Type \"" + type + "\" not recognized by DisplaySetting");
            }

            this.objType = t1.intValue();
         }

      } catch (Throwable var11) {
         if(var11 instanceof NDSRuntimeException) {
            throw (NDSRuntimeException)var11;
         } else {
            logger.error(" Type \"" + type + "\" not recognized by DisplaySetting", var11);
            throw new NDSRuntimeException(" Type \"" + type + "\" not recognized by DisplaySetting");
         }
      }
   }

   public DisplaySetting(String type, int cols, int rows, int charsPerRow) {
      Integer t = (Integer)methods.get(type);
      if(t == null) {
         throw new NDSRuntimeException(" Type \"" + type + "\" not recognized by DisplaySetting");
      } else {
         this.objType = t.intValue();
         this.rows = rows;
         this.columns = cols;
         this.charsPerRow = charsPerRow;
      }
   }

   public boolean isUIController() {
      return this.objType == 7 || this.objType == 6;
   }

   public int getCharsPerRow() {
      return this.charsPerRow;
   }

   private void checkOnColumn(Column col) {
      this.columns = 1;
      this.rows = 1;
      this.objType = 1;
      this.charsPerRow = 20;
      PairTable pt = col.getValues(TableManager.getDefaultSysLocale());
      if(pt == null) {
         switch(col.getType()) {
         case 2:
            if(col.getLength() > 256) {
               this.objType = 2;
               this.rows = 6;
               this.columns = 2;
               this.charsPerRow = 60;
            } else if(col.getLength() > 128) {
               this.columns = 2;
               this.charsPerRow = 80;
            }
         default:
         }
      } else {
         int cnt = pt.size();
         if(cnt == 2 && pt.containsKey("Y") && pt.containsKey("N")) {
            this.objType = 5;
         } else {
            this.objType = 3;
         }

      }
   }

   public int getObjectType() {
      return this.objType;
   }

   public int getRows() {
      return this.rows;
   }

   public int getColumns() {
      return this.columns;
   }

   public String toString() {
      return this.getObjectTypeString() + "(" + this.columns + "," + this.rows + ")[" + this.charsPerRow + "]";
   }

   public static void main(String[] args) {
      DisplaySetting ds = new DisplaySetting("textarea(2,2)[34]");
      System.out.println(ds);
   }

   static {
      methods.put("text", new Integer(1));
      methods.put("textarea", new Integer(2));
      methods.put("select", new Integer(3));
      methods.put("radio", new Integer(4));
      methods.put("check", new Integer(5));
      methods.put("hr", new Integer(6));
      methods.put("blank", new Integer(7));
      methods.put("file", new Integer(8));
      methods.put("image", new Integer(9));
      methods.put("button", new Integer(10));
      methods.put("clob", new Integer(11));
      methods.put("xml", new Integer(12));
      methods.put("icon", new Integer(13));
   }
}
